"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sortByCreatedDate = exports.stringFieldSorter = exports.stringSorter = void 0;
const bf_types_1 = require("bf-types");
/**
 * Generate a function to sort string values.
 *
 * @param dir The sort direction.
 */
function stringSorter(dir) {
    if (dir === 'asc') {
        return (l, r) => l.localeCompare(r);
    }
    return (l, r) => -l.localeCompare(r);
}
exports.stringSorter = stringSorter;
/**
 * Generate a function used to sort objects with a particular string field.
 *
 * @param field The name of a property on the type being sorted.
 * @param dir The sort direction.
 */
function stringFieldSorter(field, dir) {
    if (dir === 'asc') {
        return ({ [field]: l }, { [field]: r }) => l.localeCompare(r);
    }
    return ({ [field]: l }, { [field]: r }) => -l.localeCompare(r);
}
exports.stringFieldSorter = stringFieldSorter;
/**
 * Sort a collection of objects by the value of their created date field.
 *
 * @param dir The sort direction. Defaults to SortDirection.DESC.
 */
function sortByCreatedDate(dir = bf_types_1.SortDirection.DESC) {
    return stringFieldSorter(bf_types_1.ModuleProperty.CREATED_DATE, dir);
}
exports.sortByCreatedDate = sortByCreatedDate;
