/**
 * Verify that a value is an email address
 *
 * @param email A value that should be an email address
 */
export declare function isValidEmail(email?: string | null): boolean;
/**
 * Create a function which, when given a particular value, will create a function to test
 * that value against the field value of an object.
 *
 * e.g., let x = { a: 1 }; fieldEquals('a')(1)(x) === true; fieldEquals('a')(2)(x) === false;
 *
 * @param field The name of a property for an object type.
 */
export declare function fieldEquals<T>(field: keyof T): <C extends T>(value: C[keyof T]) => (item: T) => item is C;
export declare function fieldNotEquals<T>(field: keyof T): (value: any) => (item: T) => boolean;
export declare const titleEquals: <C extends {
    title: string;
}>(value: C["title"]) => (item: {
    title: string;
}) => item is C;
export declare const statusEquals: <C extends {
    status: string;
}>(value: C["status"]) => (item: {
    status: string;
}) => item is C;
export declare const idEquals: <C extends {
    id: string;
}>(value: C["id"]) => (item: {
    id: string;
}) => item is C;
export declare const idNotEquals: (value: any) => (item: {
    id: string;
}) => boolean;
/**
 * Check if a collection of arbitrary values are equal.
 *
 * @param values A collection of arbitrary values.
 */
export declare function equal(...values: any[]): boolean;
