"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.equal = exports.idNotEquals = exports.idEquals = exports.statusEquals = exports.titleEquals = exports.fieldNotEquals = exports.fieldEquals = exports.isValidEmail = void 0;
const deep_equal_1 = __importDefault(require("deep-equal"));
// eslint-disable-next-line max-len
const emailRegex = /[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?/;
/**
 * Verify that a value is an email address
 *
 * @param email A value that should be an email address
 */
function isValidEmail(email) {
    return emailRegex.test(String(email));
}
exports.isValidEmail = isValidEmail;
/**
 * Create a function which, when given a particular value, will create a function to test
 * that value against the field value of an object.
 *
 * e.g., let x = { a: 1 }; fieldEquals('a')(1)(x) === true; fieldEquals('a')(2)(x) === false;
 *
 * @param field The name of a property for an object type.
 */
function fieldEquals(field) {
    return (value) => (item) => item && item[field] === value;
}
exports.fieldEquals = fieldEquals;
function fieldNotEquals(field) {
    return (value) => (item) => item[field] !== value;
}
exports.fieldNotEquals = fieldNotEquals;
exports.titleEquals = fieldEquals('title');
exports.statusEquals = fieldEquals('status');
exports.idEquals = fieldEquals('id');
exports.idNotEquals = fieldNotEquals('id');
/**
 * Check if a collection of arbitrary values are equal.
 *
 * @param values A collection of arbitrary values.
 */
function equal(...values) {
    if (values.length === 0) {
        return true;
    }
    const firstValue = values[0];
    for (let i = 1; i < values.length; i++) {
        if (!deep_equal_1.default(firstValue, values[i])) {
            return false;
        }
    }
    return true;
}
exports.equal = equal;
